@@ -1299,7 +1299,7 @@ class Api:
         Execute an action on a drive
         """
         log.debug("Running function")
-        endpoint = "/sep/api/v2/drive/{}/execute".format(id)
+        endpoint = "/sep/api/v2/drives/{}/execute".format(id)
         data = {"action": action}
         url = self._urlexpand(endpoint)
         response = requests.post(url=url, headers=self.headers, json=data, verify=self.verify)
